pub enum ImgGenSpecError {
InvalidLayerHeight,
InvalidCssColor {
value: String,
reason: String,
},
InvalidGradientSpec {
reason: String,
},
}Expand description
Errors produced while validating or parsing image generation specifications.
Variants
InvalidLayerHeight
Returned when a layer height would evaluate to zero.
InvalidCssColor
Returned when a CSS color string cannot be parsed.
Fields
InvalidGradientSpec
Returned when a gradient specification cannot be converted into a gradient.