pub struct LinearGradient {
pub start: LayerOffset,
pub end: LayerOffset,
pub spread: Spread,
/* private fields */
}Expand description
A data structure to represent a linear gradient
Fields
start: LayerOffsetThe gradient starting point (Offset).
end: LayerOffsetThe gradient ending point (Offset).
spread: SpreadThe gradient Spread
Implementations
Sourceimpl LinearGradient
impl LinearGradient
Sourcepub fn new(
colors: ColorGradient,
start: LayerOffset,
end: LayerOffset,
spread: Option<Spread>,
) -> LinearGradient
pub fn new( colors: ColorGradient, start: LayerOffset, end: LayerOffset, spread: Option<Spread>, ) -> LinearGradient
Creates a linear gradient from colors, start, end,
and an optional spread mode.
Sourcepub fn get_color_at(&self, x: u32, y: u32) -> SolidColor
pub fn get_color_at(&self, x: u32, y: u32) -> SolidColor
A helper function for renderers to get the color at a certain point.
The given x and y values are the coordinate of the pixel in the Layer
(relative to Layer::offset).